
cc.Class({
    extends: cc.Component,
    properties: {
        layerPrefab: null,
        pageviewPrefab: null,
        pagePrefab: null,
        editboxPrefab: null,

        _game_node: null,
        _q_pageview: null,
    },

    initNodes: function() {
        this._game_node = cc.find('Canvas/Main/Game');
        this._game_main_node = cc.find('Canvas/Main/Game/Main');
    },

    initGame: function() {
        var self = this;

        this._json = { 
            size: {w: 15, h: 14}, 
            clues: [
                {index:1, horizontal: true, text: "Hello page 1" }, 
                {index:2, horizontal: true, text: "Hello page 2" }, 
            ]
        }

        cc.loader.loadResArray(['prefabs/layer', 'prefabs/pageview', 'prefabs/page', 'prefabs/editbox'], function(err, prefabs) {
            self.layerPrefab = prefabs[0];
            self.pageviewPrefab = prefabs[1];
            self.pagePrefab = prefabs[2];
            self.editboxPrefab = prefabs[3];

            self.createNewLayer();
        });
    },

    createNewLayer() {
        var self = this;
        var q_layer = cc.instantiate(this.layerPrefab);
        q_layer.name = 'New Layer';
        q_layer.getComponent(cc.Sprite).spriteFrame = null;
        q_layer.parent = this._game_main_node;
        q_layer.height = 150;

        let w = q_layer.getComponent(cc.Widget);
        w.isAlignBottom = true;
        
        const pageview = this.addPageview(q_layer);

        this._q_layer = q_layer;

        this.scheduleOnce( () => {
            for(var i = 0; i < this._json.clues.length; i++){
                self.createPage(pageview, this._json.clues[i]);
            };

            self._q_pageview = pageview;
        }, 0.001);
    },

    addPageview: function(node) {

        node.children[0].active = false;
        node.children[1].active = false;

        var pageview_node = cc.instantiate(this.pageviewPrefab);
        // bg
        pageview_node.children[0].getComponent(cc.Sprite).spriteFrame = null;
        pageview_node.parent = node;
        pageview_node.setPosition(0, 0);
        
        var pageview = pageview_node.getComponent(cc.PageView);
        pageview.horizontal = true;
        pageview.vertical = false;
        pageview.indicator.node.active = false;
        
        var w = pageview_node.addComponent(cc.Widget);
        w.target = node;
        w.isAlignLeft = true;
        w.isAlignRight = true;
        w.isAlignBottom = true;
        w.alignMode = cc.Widget.AlignMode.ALWAYS;
        w.left = 0;
        w.right = 0;
        w.updateAlignment();

        var layout = pageview.content.getComponent(cc.Layout);
        layout.resizeMode = 1;
        layout.type = 1;
        layout.spacingY = 10;
        layout.spacingX = 0;

        var view_node = pageview.content.parent;
        w = view_node.addComponent(cc.Widget);
        w.target = pageview_node;
        w.isAlignLeft = true;
        w.isAlignRight = true;
        w.left = 0;
        w.right = 0;
        w.updateAlignment();
                
        view_node.setContentSize(pageview_node.width, pageview_node.height);

        return pageview;
    },

    createPage: function(container, clue_data){

        var text = {
            size: 40,
            color: {
                r: 255,
                g: 255,
                b: 155,
            },
        };

    	var self = this;
        var q_node = cc.instantiate(this.pagePrefab);
        // q_node.getComponent(cc.Sprite).spriteFrame = null;
        q_node.name = 'Page';

        var layout_node = q_node.children[0];
        layout_node.getComponent(cc.Layout).spacingY = 0;

        var title_node = layout_node.children[0];
        var page_node = layout_node.children[1];

        if(text){
            if(text.font){
                title_node.getComponent(cc.Label).fontFamily = text.font;
                page_node.getComponent(cc.Label).fontFamily = text.font;
            }
            if(text.size){
                title_node.getComponent(cc.Label).fontSize = text.size;
                page_node.getComponent(cc.Label).fontSize = text.size;
                title_node.getComponent(cc.Label).lineHeight = text.size;
                page_node.getComponent(cc.Label).lineHeight = text.size;
            }
            if(text.color){
                title_node.runAction(cc.tintTo(0, text.color.r, text.color.g, text.color.b));
                page_node.runAction(cc.tintTo(0, text.color.r, text.color.g, text.color.b));
            }
        }

        let question_text = clue_data.text;
        var dir_text = '';

        let title_text = clue_data.index + '. ' + dir_text;
        title_node.getComponent(cc.Label).string = title_text;   
        page_node.getComponent(cc.Label).string = question_text;

        var inputfield = cc.instantiate(self.editboxPrefab);
        inputfield.getComponent(cc.EditBox).maxLength = 10;
        inputfield.getComponent(cc.EditBox).placeholder = 10 + ' stars'
        inputfield.parent = layout_node;
        inputfield.setContentSize(200, 60);
        // inputfield.on('editing-return', self.onAnswerEntered, self);

        q_node.setContentSize(container.node.width, container.node.height);

        container.addPage(q_node);
	},


    // LIFE-CYCLE CALLBACKS:

    // onLoad () {},

    start () {
        this.initNodes();
        this.initGame();
    },

    update (dt) {
        if(this._q_layer){
                this._q_layer.setPosition(this._game_main_node.width / 2, this._game_main_node.height / 2 );
                this._q_layer.width = this._game_main_node.width;
            }
    },
});
